==> zio-aws-rds_3-5.17.155.1-sources.jar: zio/aws/rds/model/DBParameterGroup.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class DBParameterGroup(
    dbParameterGroupName: scala.Option[String] = None,
    dbParameterGroupFamily: scala.Option[String] = None,
    description: scala.Option[String] = None,
    dbParameterGroupArn: scala.Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DBParameterGroup = {
    import DBParameterGroup.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DBParameterGroup
      .builder()
      .optionallyWith(
        dbParameterGroupName.map(value => value: java.lang.String)
      )(_.dbParameterGroupName)
      .optionallyWith(
        dbParameterGroupFamily.map(value => value: java.lang.String)
      )(_.dbParameterGroupFamily)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(
        dbParameterGroupArn.map(value => value: java.lang.String)
      )(_.dbParameterGroupArn)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.DBParameterGroup.ReadOnly =
    zio.aws.rds.model.DBParameterGroup.wrap(buildAwsValue())
}
object DBParameterGroup {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DBParameterGroup
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DBParameterGroup =
      zio.aws.rds.model.DBParameterGroup(
        dbParameterGroupName.map(value => value),
        dbParameterGroupFamily.map(value => value),
        description.map(value => value),
        dbParameterGroupArn.map(value => value)
      )
    def dbParameterGroupName: scala.Option[String]
    def dbParameterGroupFamily: scala.Option[String]
    def description: scala.Option[String]
    def dbParameterGroupArn: scala.Option[String]
    def getDbParameterGroupName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbParameterGroupName", dbParameterGroupName)
    def getDbParameterGroupFamily: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("dbParameterGroupFamily", dbParameterGroupFamily)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getDbParameterGroupArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbParameterGroupArn", dbParameterGroupArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DBParameterGroup
  ) extends zio.aws.rds.model.DBParameterGroup.ReadOnly {
    override val dbParameterGroupName: scala.Option[String] =
      scala.Option(impl.dbParameterGroupName()).map(value => value: String)
    override val dbParameterGroupFamily: scala.Option[String] =
      scala.Option(impl.dbParameterGroupFamily()).map(value => value: String)
    override val description: scala.Option[String] =
      scala.Option(impl.description()).map(value => value: String)
    override val dbParameterGroupArn: scala.Option[String] =
      scala.Option(impl.dbParameterGroupArn()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DBParameterGroup
  ): zio.aws.rds.model.DBParameterGroup.ReadOnly = new Wrapper(impl)
}

==> zio-aws-rds_3-7.21.15.13-sources.jar: zio/aws/rds/model/DBParameterGroup.scala <==
package zio.aws.rds.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class DBParameterGroup(
    dbParameterGroupName: Optional[String] = Optional.Absent,
    dbParameterGroupFamily: Optional[String] = Optional.Absent,
    description: Optional[String] = Optional.Absent,
    dbParameterGroupArn: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.rds.model.DBParameterGroup = {
    import DBParameterGroup.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.rds.model.DBParameterGroup
      .builder()
      .optionallyWith(
        dbParameterGroupName.map(value => value: java.lang.String)
      )(_.dbParameterGroupName)
      .optionallyWith(
        dbParameterGroupFamily.map(value => value: java.lang.String)
      )(_.dbParameterGroupFamily)
      .optionallyWith(description.map(value => value: java.lang.String))(
        _.description
      )
      .optionallyWith(
        dbParameterGroupArn.map(value => value: java.lang.String)
      )(_.dbParameterGroupArn)
      .build()
  }
  def asReadOnly: zio.aws.rds.model.DBParameterGroup.ReadOnly =
    zio.aws.rds.model.DBParameterGroup.wrap(buildAwsValue())
}
object DBParameterGroup {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.rds.model.DBParameterGroup
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.rds.model.DBParameterGroup =
      zio.aws.rds.model.DBParameterGroup(
        dbParameterGroupName.map(value => value),
        dbParameterGroupFamily.map(value => value),
        description.map(value => value),
        dbParameterGroupArn.map(value => value)
      )
    def dbParameterGroupName: Optional[String]
    def dbParameterGroupFamily: Optional[String]
    def description: Optional[String]
    def dbParameterGroupArn: Optional[String]
    def getDbParameterGroupName: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbParameterGroupName", dbParameterGroupName)
    def getDbParameterGroupFamily: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("dbParameterGroupFamily", dbParameterGroupFamily)
    def getDescription: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("description", description)
    def getDbParameterGroupArn: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("dbParameterGroupArn", dbParameterGroupArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.rds.model.DBParameterGroup
  ) extends zio.aws.rds.model.DBParameterGroup.ReadOnly {
    override val dbParameterGroupName: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.dbParameterGroupName())
      .map(value => value: String)
    override val dbParameterGroupFamily: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dbParameterGroupFamily())
        .map(value => value: String)
    override val description: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.description())
      .map(value => value: String)
    override val dbParameterGroupArn: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.dbParameterGroupArn())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.rds.model.DBParameterGroup
  ): zio.aws.rds.model.DBParameterGroup.ReadOnly = new Wrapper(impl)
}
